summaryrefslogtreecommitdiffstats
path: root/kbabel/kbabel/mymultilineedit.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60 (patch)
treebabc4a761925023e16fa94633959f35d1c251887 /kbabel/kbabel/mymultilineedit.h
parent0813b39aed2cf4c84157a22c4c9594336d93d412 (diff)
downloadtdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.tar.gz
tdesdk-22253cd8fbc0bd2e70f32aaf1f95ea3a3e819a60.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdesdk@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kbabel/kbabel/mymultilineedit.h')
-rw-r--r--kbabel/kbabel/mymultilineedit.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kbabel/kbabel/mymultilineedit.h b/kbabel/kbabel/mymultilineedit.h
index bc0075d0..272878da 100644
--- a/kbabel/kbabel/mymultilineedit.h
+++ b/kbabel/kbabel/mymultilineedit.h
@@ -52,7 +52,7 @@ class MyMultiLineEdit : public KTextEdit
Q_OBJECT
TQ_OBJECT
public:
- MyMultiLineEdit(int ID,TQWidget* tqparent,const char* name=0);
+ MyMultiLineEdit(int ID,TQWidget* parent,const char* name=0);
/**
applies cmd to the displayed text, but does not emit
@@ -130,7 +130,7 @@ protected:
virtual TQPopupMenu *createPopupMenu();
virtual TQPopupMenu *createPopupMenu(const TQPoint &pos);
/* the tqparent handles this */
virtual void wheelEvent(TQWheelEvent*);
bool emitUndo;
@@ -178,7 +178,7 @@ class MsgMultiLineEdit : public MyMultiLineEdit
public:
enum TextColor { NormalColor, ErrorColor };
- MsgMultiLineEdit(int ID, KSpell* spell=0, TQWidget* tqparent=0,const char* name=0);
+ MsgMultiLineEdit(int ID, KSpell* spell=0, TQWidget* parent=0,const char* name=0);
virtual ~MsgMultiLineEdit();
/** is displaying surrounding quotes enabled? */
@@ -130,7 +130,7 @@ protected:
virtual TQPopupMenu *createPopupMenu();
virtual TQPopupMenu *createPopupMenu(const TQPoint &pos);
- /* the tqparent handles this */
+ /* the parent handles this */
virtual void wheelEvent(TQWheelEvent*);
bool emitUndo;